<?xml version="1.0" encoding="UTF-8"?>
<!--
********************************************************************
*  Licensed Materials - Property of IBM 
*
*  5724-C07 
*
*  (c) Copyright IBM Corp.  2001, 2004 All Rights Reserved
* 
*  US Government Users Restricted Rights - Use, duplication or
*  disclosure restricted by GSA ADP Schedule Contract with
*  IBM Corp.
*********************************************************************

*********************************************************************
* File, Component, Release:
* %W%
*
* Version: %I%
*
* Date and Time File was last checked in:       %E% %U%
* Date and Time File was extracted/checked out: %D% %T%
*
* Description:
*
* Change History:
*
* mm/dd/yyyy userid   track    change history description here
* ********** ******   *****    **************************************
*            plachco  f6172    Intial Code Creation
* 01/23/2004 jharter  d6540    Handle no start/finish times specified
* 01/23/2004 jharter  d6550    No matching records, show msg not Jan 1,1970
* 02/01/2004 sudhakar d6586    XSLT was not able to handle more than
*                              one filtered value
* 02/05/2004 jharter  d6634    Convert segment loop to apply-template
* 03/19/2004 plachco  d6550f_1 Prevent a link when there are no records to show
*********************************************************************
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:lxslt="http://xml.apache.org/xslt"
                xmlns:localizer="xalan://com.ibm.btb.tools.archive.view.XSLTLocalizer"
                exclude-result-prefixes="localizer"
                version="1.0">

<!-- *********************************************************************** 
     Imports for individual report stylesheets
     *********************************************************************** -->
<xsl:import href="common.xsl"/>
<xsl:variable name="basedir"   select="''"/>
<xsl:variable name="relative"   select="localizer:getRootRelativeToIndex($xsltLocalizer)"/>
<xsl:variable name="title" select="localizer:getTableOfContentsTitle($xsltLocalizer)"/>

<!-- *********************************************************************** 
     HTML Variables
     *********************************************************************** -->
<xsl:variable name="FULL-WIDTH" select="'100%'"/>
<xsl:variable name="TIME-WIDTH" select="'20%'"/>
<xsl:variable name="STAMP-WIDTH" select="'80%'"/>
<xsl:variable name="TAG-WIDTH" select="'50%'"/>
<xsl:variable name="FILTER-WIDTH" select="'50%'"/>
<xsl:variable name="current-index" select="0"/>

<!-- *************************************************************************************************************
     *                                           M E T A D A T A                                                 *
     *************************************************************************************************************-->
<xsl:template match="metadata">        

   <TABLE cellspacing="0" cellpadding="0" width="100%" border="0">
       <TR>
         <TD align="middle" width="100%">
            <FONT class="title"><xsl:value-of select="$title"/></FONT>
          </TD>
       </TR>
   </TABLE>
   <BR/>
    <!-- Emit table header -->           
   <TABLE cellSpacing="0" cellPadding="0" width="94%" align="center" border="0">
      <TBODY>
         <TR>
            <TD>
               <!-- Filtered Criteria Section -->
               <xsl:apply-templates select="criteria"/>
               
               <!-- Archived Files Scanned Section -->
               <xsl:apply-templates select="archives"/>
               
               <!-- Filtered Results Section -->
               <xsl:apply-templates select="segments"/>
               
            </TD>
         </TR>
      </TBODY>
    </TABLE>

</xsl:template>              

<!-- *************************************************************************************************************
     *                                     F I L T E R E D   C R I T E R I A                                     *
     *************************************************************************************************************-->
<xsl:template match="criteria">        

  <!-- Emit Criteria header -->
   <xsl:call-template name="emitSmallSpacing"/>
   <xsl:variable name="subSectionLabel" select="localizer:getString($xsltLocalizer, string('KEY_METADATA_CRITERIA_TITLE'))"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
  
   <!-- Format the end time string (blank if no end-time was specified) -->
   <xsl:variable name="endtime-string">
    <xsl:choose>
     <xsl:when test="@endtime">      
       <xsl:variable name="end-time" select="@endtime"/>
       <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($end-time))"/>
       <xsl:value-of select="$HTML-SPACE"/>
       <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($end-time))"/>
     </xsl:when>          
     <xsl:otherwise>
       <xsl:value-of select="$HTML-SPACE"/>
     </xsl:otherwise>
    </xsl:choose> 
   </xsl:variable>               
 
   <!-- Format the start time string (blank if no start-time was specified) -->
   <xsl:variable name="starttime-string">
    <xsl:choose>
     <xsl:when test="@starttime">      
       <xsl:variable name="start-time" select="@starttime"/>   
       <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($start-time))"/>
       <xsl:value-of select="$HTML-SPACE"/>
       <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($start-time))"/>
     </xsl:when>          
     <xsl:otherwise>
       <xsl:value-of select="$HTML-SPACE"/>
     </xsl:otherwise>
    </xsl:choose> 
   </xsl:variable>
   
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
      <!-- Emit Starting Timestamp Infomation -->
      <TR>
          <TH width="{$TIME-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_METADATA_CRITERIA_START_TIME'))"/></TH>
          <TD width="{$STAMP-WIDTH}" class="genericTableCellRpt"><xsl:value-of select="$starttime-string"/></TD>
      </TR>

      <!-- Emit Ending Timestamp Information-->
      <TR>
          <TH width="{$TIME-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_METADATA_CRITERIA_END_TIME'))"/></TH>
          <TD width="{$STAMP-WIDTH}" class="genericTableCellRpt"><xsl:value-of select="$endtime-string"/></TD>
      </TR>
   </TBODY>
   </TABLE>

   <xsl:call-template name="emitSmallSpacing"/>

   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
      <!-- Emit Tag-Filter Infomation Header -->
      <TR>
          <TH width="{$TAG-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_METADATA_CRITERIA_TAG'))"/></TH>
          <TH width="{$FILTER-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_METADATA_CRITERIA_FILTER'))"/></TH>
      </TR>

	   <!-- Emit the Search Filters -->
	   <xsl:apply-templates select="./search"/>      
   </TBODY>
   </TABLE>

</xsl:template>

<!-- Search Filter -->
<xsl:template match="search">
    
   <!-- Retrieve Tag-->
   <xsl:variable name="tag-name">
     <xsl:choose>
         <xsl:when test="string-length(@tag) != 0">
             <xsl:value-of select="@tag"/>            
         </xsl:when>
         <xsl:otherwise>
             <xsl:value-of select="$HTML-SPACE"/>
         </xsl:otherwise>
     </xsl:choose> 
   </xsl:variable>              

   <xsl:variable name="numFilters">
     <xsl:value-of select="count(./filter)"/>
   </xsl:variable>

   <xsl:variable name="filter-value1">
     <xsl:choose>
         <xsl:when test="./filter[1]/@value">
             <xsl:value-of select="./filter[1]/@value"/>
         </xsl:when>
         <xsl:otherwise>
             <xsl:value-of select="$HTML-SPACE"/>
         </xsl:otherwise>
     </xsl:choose> 
   </xsl:variable>

   <TR>
      <TD class="genericTableCellRpt" rowspan="{$numFilters}" colspan="1" ><xsl:value-of select="$tag-name"/></TD>
      <TD class="genericTableCellRpt"><xsl:value-of select="$filter-value1"/></TD>
   </TR>

   <xsl:for-each select="./filter[position()!=1]">

	   <xsl:variable name="filter-value">
	     <xsl:choose>
	         <xsl:when test="@value">
	             <xsl:value-of select="@value"/>
	         </xsl:when>
	         <xsl:otherwise>
	             <xsl:value-of select="$HTML-SPACE"/>
	         </xsl:otherwise>
	     </xsl:choose> 
	    </xsl:variable>

        <TR>
            <TD class="genericTableCellRpt"><xsl:value-of select="$filter-value"/></TD>
        </TR>

   </xsl:for-each>
</xsl:template>

<!-- *************************************************************************************************************
     *                                     A R C H I V E D  F I L E S  S C A N N E D                             *
     *************************************************************************************************************-->
<xsl:template match="archives">        

  <!-- Emit Archive Files header -->
   <xsl:call-template name="emitSmallSpacing"/>
   <xsl:variable name="subSectionLabel" select="localizer:getString($xsltLocalizer, string('KEY_METADATA_ARCHIVED_TITLE'))"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
  
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
   	   <TR>
	       <TH width="{$FULL-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_METADATA_ARCHIVED_PATH_LOCATION'))"/></TH>
       </TR>
   <xsl:for-each select="./archive">

	   <xsl:variable name="archive-path">
	     <xsl:choose>
	         <xsl:when test="@path">
	             <xsl:value-of select="@path"/>
	         </xsl:when>
	         <xsl:otherwise>
	             <xsl:value-of select="$HTML-SPACE"/>
	         </xsl:otherwise>
	     </xsl:choose> 
	    </xsl:variable>

      <!-- Emit Archive File Infomation -->
        <TR>
            <TD class="genericTableCellRpt"><xsl:value-of select="$archive-path"/></TD>
        </TR>
   </xsl:for-each>
   </TBODY>
   </TABLE>

   <xsl:call-template name="emitSmallSpacing"/>
</xsl:template>

<!-- *************************************************************************************************************
     *                                     F I L T E R E D  S E G M E N T S  R E S U L T S                       *
     *************************************************************************************************************-->
<xsl:template match="segments">

    <!-- Emit Filtered Results segment header -->
    <xsl:call-template name="emitSmallSpacing"/>
    <xsl:variable name="subSectionLabel" select="localizer:getString($xsltLocalizer, string('KEY_METADATA_SEGMENT_TITLE'))"/>
    <xsl:call-template name="emitHeader-Section">
        <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
    </xsl:call-template>               
    <xsl:call-template name="emitSmallSpacing"/>
  
    <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
    <TBODY>
   		<TR>
 	       <TH width="{$FULL-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_METADATA_SEGMENT_TIMERANGE'))"/></TH>
        </TR>
	    <xsl:apply-templates select="segment"/> <!-- jlh 6634 -->
    </TBODY>
    </TABLE>

    <xsl:call-template name="emitSmallSpacing"/>
</xsl:template>

<xsl:template match="segment"> <!-- jlh 6634 -->
    <xsl:variable name="start-time" select="@starttime"/> <!-- jlh 6634 -->
    
    <xsl:variable name="starttime-string">
       <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($start-time))"/>
       <xsl:value-of select="$HTML-SPACE"/>
       <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($start-time))"/>
    </xsl:variable>               

    <xsl:variable name="end-time" select="@endtime"/>  <!-- jlh 6634 -->
    
    <xsl:variable name="endtime-string">
       <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($end-time))"/>
       <xsl:value-of select="$HTML-SPACE"/>
       <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($end-time))"/>
    </xsl:variable>               

	<xsl:variable name="summary-report-location" select="localizer:getSummaryPageRelativeToIndex($xsltLocalizer, position())"/> <!-- jlh 6634 -->
    
    <!-- Emit Segment Time Range Infomation -->
    <TR>
        <TD class="genericTableCellRpt">
        	<xsl:choose>
        	  <xsl:when test="$start-time='0'">
        	    <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_METADATA_SEGMENT_NO_RECORDS'))"/>
        	  </xsl:when>
        	  <xsl:otherwise>
	        	<A href="{$summary-report-location}">
	        	    <xsl:value-of select="$starttime-string"/> - <xsl:value-of select="$endtime-string"/>
	        	</A>
        	  </xsl:otherwise>
        	</xsl:choose>
        </TD>
    </TR>
    <!-- jlh 6634 loop code deleted -->
</xsl:template>

</xsl:stylesheet>